@@ -1,15 +1,17 @@
 import errno
+import os
 import socket
 import time
 
+from .base import BaseEnvironment
+from ..utils import ErrorExit, _get_juju_home, yaml_load
+
 from jujuclient import (
     EnvError,
     Environment as EnvironmentClient,
     UnitErrors,
 )
 
-from .base import BaseEnvironment
-from ..utils import ErrorExit
 from .watchers import (
     raise_on_errors,
     WaitForMachineTermination,
@@ -26,8 +28,23 @@ class GoEnvironment(BaseEnvironment):
         self.client = None
 
     def _get_token(self):
-        config = self._get_env_config()
-        return config['admin-secret']
+        home = _get_juju_home()
+        jenv = os.path.join(
+            home, 'environments', '%s.jenv' % self.name)
+        if not os.path.exists(jenv):
+            with open(os.path.join(home, 'environments.yaml')) as fh:
+                data = yaml_load(fh.read())
+                token = data.get('environments', {}).get(self.name, {}).get(
+                    'admin-secret')
+                if token is None:
+                    raise EnvError("Environment config not found")
+        with open(jenv) as fh:
+            data = yaml_load(fh.read())
+            token = data.get('bootstrap-config', {}).get(
+                'admin-secret')
+            if token is None:
+                raise EnvError("Could not find admin-secret for environment")
+        return token
 
     def add_unit(self, service_name, machine_spec):
         return self.client.add_unit(service_name, machine_spec)
