@@ -350,3 +350,24 @@ def get_qualified_charm_url(url):
     content = json.loads(fh.read())
     rev = content[url]['revision']
     return "%s-%d" % (url, rev)
+
+
+def get_env_name(param_env_name):
+    """Get the environment name.
+
+    """
+    if param_env_name:
+        return param_env_name
+    elif os.environ.get("JUJU_ENV"):
+        return os.environ['JUJU_ENV']
+
+    juju_home = _get_juju_home()
+    env_ptr = os.path.join(juju_home, "current-environment")
+    if os.path.exists(env_ptr):
+        with open(env_ptr) as fh:
+            return fh.read().strip()
+
+    with open(os.path.join(juju_home, 'environments.yaml')) as fh:
+        conf = yaml_load(fh.read())
+        if not 'default' in conf:
+            raise ValueError("No Environment specified")
